@@ -20,7 +20,6 @@ import (
 	"github.com/helmfile/helmfile/pkg/helmexec"
 	"github.com/helmfile/helmfile/pkg/plugins"
 	"github.com/helmfile/helmfile/pkg/remote"
-	"github.com/helmfile/helmfile/pkg/runtime"
 	"github.com/helmfile/helmfile/pkg/state"
 )
 
@@ -139,25 +138,6 @@ func (a *App) Repos(c ReposConfigProvider) error {
 	}, c.IncludeTransitiveNeeds(), SetFilter(true))
 }
 
-// TODO: Remove this function once Helmfile v0.x
-func (a *App) DeprecatedSyncCharts(c DeprecatedChartsConfigProvider) error {
-	return a.ForEachState(func(run *Run) (_ bool, errs []error) {
-		err := run.withPreparedCharts("charts", state.ChartPrepareOptions{
-			SkipRepos:   true,
-			SkipDeps:    true,
-			Concurrency: 2,
-		}, func() {
-			errs = run.DeprecatedSyncCharts(c)
-		})
-
-		if err != nil {
-			errs = append(errs, err)
-		}
-
-		return
-	}, c.IncludeTransitiveNeeds(), SetFilter(true))
-}
-
 func (a *App) Diff(c DiffConfigProvider) error {
 	var allDiffDetectedErrs []error
 
@@ -410,7 +390,7 @@ func (a *App) Apply(c ApplyConfigProvider) error {
 
 	var opts []LoadOption
 
-	opts = append(opts, SetRetainValuesFiles(c.RetainValuesFiles() || c.SkipCleanup()))
+	opts = append(opts, SetRetainValuesFiles(c.SkipCleanup()))
 
 	err := a.ForEachState(func(run *Run) (ok bool, errs []error) {
 		includeCRDs := !c.SkipCRDs()
@@ -423,7 +403,7 @@ func (a *App) Apply(c ApplyConfigProvider) error {
 			WaitRetries:            c.WaitRetries(),
 			WaitForJobs:            c.WaitForJobs(),
 			IncludeCRDs:            &includeCRDs,
-			SkipCleanup:            c.RetainValuesFiles() || c.SkipCleanup(),
+			SkipCleanup:            c.SkipCleanup(),
 			Validate:               c.Validate(),
 			Concurrency:            c.Concurrency(),
 			IncludeTransitiveNeeds: c.IncludeNeeds(),
@@ -475,31 +455,6 @@ func (a *App) Status(c StatusesConfigProvider) error {
 	}, false, SetFilter(true))
 }
 
-// TODO: Remove this function once Helmfile v0.x
-func (a *App) Delete(c DeleteConfigProvider) error {
-	return a.ForEachState(func(run *Run) (ok bool, errs []error) {
-		if !c.SkipCharts() {
-			err := run.withPreparedCharts("delete", state.ChartPrepareOptions{
-				SkipRepos:     c.SkipRefresh() || c.SkipDeps(),
-				SkipRefresh:   c.SkipRefresh(),
-				SkipDeps:      c.SkipDeps(),
-				Concurrency:   c.Concurrency(),
-				DeleteWait:    c.DeleteWait(),
-				DeleteTimeout: c.DeleteTimeout(),
-			}, func() {
-				ok, errs = a.delete(run, c.Purge(), c)
-			})
-
-			if err != nil {
-				errs = append(errs, err)
-			}
-		} else {
-			ok, errs = a.delete(run, c.Purge(), c)
-		}
-		return
-	}, false, SetReverse(true))
-}
-
 func (a *App) Destroy(c DestroyConfigProvider) error {
 	return a.ForEachState(func(run *Run) (ok bool, errs []error) {
 		if !c.SkipCharts() {
@@ -1050,7 +1005,7 @@ func printDAG(batches [][]state.Release) string {
 	for i, batch := range batches {
 		for _, r := range batch {
 			id := state.ReleaseToID(&r.ReleaseSpec)
-			needs := r.ReleaseSpec.Needs
+			needs := r.Needs
 			_, _ = fmt.Fprintf(w, "%d\t%s\t%s\n", i+1, id, strings.Join(needs, ", "))
 		}
 	}
@@ -1151,13 +1106,17 @@ func (a *App) visitStatesWithSelectorsAndRemoteSupport(fileOrDir string, converg
 		}
 	}
 
-	// pre-overrides HelmState
+	// pre-handles HelmState
 	fHelmStatsWithOverrides := func(st *state.HelmState) (bool, []error) {
 		var err error
+		// override release settings
 		st.Releases, err = st.GetReleasesWithOverrides()
 		if err != nil {
 			return false, []error{err}
 		}
+
+		// override release labels
+		st.Releases = st.GetReleasesWithLabels()
 		return f(st)
 	}
 
@@ -1260,16 +1219,6 @@ func (a *App) findDesiredStateFiles(specifiedPath string, opts LoadOpts) ([]stri
 
 		case a.fs.FileExistsAt(DefaultGotmplHelmfile):
 			defaultFile = DefaultGotmplHelmfile
-
-		// TODO: Remove this block when we remove v0 code
-		case !runtime.V1Mode && a.fs.FileExistsAt(DeprecatedHelmfile):
-			a.Logger.Warnf(
-				"warn: %s is being loaded: %s is deprecated in favor of %s. See https://github.com/roboll/helmfile/issues/25 for more information",
-				DeprecatedHelmfile,
-				DeprecatedHelmfile,
-				DefaultHelmfile,
-			)
-			defaultFile = DeprecatedHelmfile
 		}
 
 		switch {
@@ -1324,7 +1273,6 @@ func (a *App) getSelectedReleases(r *Run, includeTransitiveNeeds bool) ([]state.
 	selectedIds := map[string]state.ReleaseSpec{}
 	selectedCounts := map[string]int{}
 	for _, r := range selected {
-		r := r
 		id := state.ReleaseToID(&r)
 		selectedIds[id] = r
 		selectedCounts[id]++
@@ -1338,7 +1286,6 @@ func (a *App) getSelectedReleases(r *Run, includeTransitiveNeeds bool) ([]state.
 
 	groupsByID := map[string][]*state.ReleaseSpec{}
 	for _, r := range allReleases {
-		r := r
 		groupsByID[state.ReleaseToID(&r)] = append(groupsByID[state.ReleaseToID(&r)], &r)
 	}
 
@@ -1434,14 +1381,16 @@ func (a *App) apply(r *Run, c ApplyConfigProvider) (bool, bool, []error) {
 		Context:                 c.Context(),
 		Output:                  c.DiffOutput(),
 		Set:                     c.Set(),
-		SkipCleanup:             c.RetainValuesFiles() || c.SkipCleanup(),
+		SkipCleanup:             c.SkipCleanup(),
 		SkipDiffOnInstall:       c.SkipDiffOnInstall(),
 		ReuseValues:             c.ReuseValues(),
 		ResetValues:             c.ResetValues(),
 		DiffArgs:                c.DiffArgs(),
 		PostRenderer:            c.PostRenderer(),
 		PostRendererArgs:        c.PostRendererArgs(),
+		SkipSchemaValidation:    c.SkipSchemaValidation(),
 		SuppressOutputLineRegex: c.SuppressOutputLineRegex(),
+		TakeOwnership:           c.TakeOwnership(),
 	}
 
 	infoMsg, releasesToBeUpdated, releasesToBeDeleted, errs := r.diff(false, detailedExitCode, c, diffOpts)
@@ -1545,7 +1494,7 @@ Do you really want to apply?
 
 				syncOpts := &state.SyncOpts{
 					Set:                  c.Set(),
-					SkipCleanup:          c.RetainValuesFiles() || c.SkipCleanup(),
+					SkipCleanup:          c.SkipCleanup(),
 					SkipCRDs:             c.SkipCRDs(),
 					Wait:                 c.Wait(),
 					WaitRetries:          c.WaitRetries(),
@@ -1558,6 +1507,7 @@ Do you really want to apply?
 					SyncArgs:             c.SyncArgs(),
 					HideNotes:            c.HideNotes(),
 					TakeOwnership:        c.TakeOwnership(),
+					SyncReleaseLabels:    c.SyncReleaseLabels(),
 				}
 				return subst.SyncReleases(&affectedReleases, helm, c.Values(), c.Concurrency(), syncOpts)
 			}))
@@ -1685,6 +1635,7 @@ func (a *App) diff(r *Run, c DiffConfigProvider) (*string, bool, bool, []error)
 			PostRendererArgs:        c.PostRendererArgs(),
 			SkipSchemaValidation:    c.SkipSchemaValidation(),
 			SuppressOutputLineRegex: c.SuppressOutputLineRegex(),
+			TakeOwnership:           c.TakeOwnership(),
 		}
 
 		filtered := &Run{
@@ -1943,18 +1894,20 @@ Do you really want to sync?
 				subst.Releases = rs
 
 				opts := &state.SyncOpts{
-					Set:              c.Set(),
-					SkipCRDs:         c.SkipCRDs(),
-					Wait:             c.Wait(),
-					WaitRetries:      c.WaitRetries(),
-					WaitForJobs:      c.WaitForJobs(),
-					ReuseValues:      c.ReuseValues(),
-					ResetValues:      c.ResetValues(),
-					PostRenderer:     c.PostRenderer(),
-					PostRendererArgs: c.PostRendererArgs(),
-					SyncArgs:         c.SyncArgs(),
-					HideNotes:        c.HideNotes(),
-					TakeOwnership:    c.TakeOwnership(),
+					Set:                  c.Set(),
+					SkipCRDs:             c.SkipCRDs(),
+					Wait:                 c.Wait(),
+					WaitRetries:          c.WaitRetries(),
+					WaitForJobs:          c.WaitForJobs(),
+					ReuseValues:          c.ReuseValues(),
+					ResetValues:          c.ResetValues(),
+					PostRenderer:         c.PostRenderer(),
+					PostRendererArgs:     c.PostRendererArgs(),
+					SyncArgs:             c.SyncArgs(),
+					HideNotes:            c.HideNotes(),
+					TakeOwnership:        c.TakeOwnership(),
+					SkipSchemaValidation: c.SkipSchemaValidation(),
+					SyncReleaseLabels:    c.SyncReleaseLabels(),
 				}
 				return subst.SyncReleases(&affectedReleases, helm, c.Values(), c.Concurrency(), opts)
 			}))
@@ -1982,16 +1935,17 @@ func (a *App) template(r *Run, c TemplateConfigProvider) (bool, []error) {
 		}
 
 		opts := &state.TemplateOpts{
-			Set:               c.Set(),
-			IncludeCRDs:       c.IncludeCRDs(),
-			NoHooks:           c.NoHooks(),
-			OutputDirTemplate: c.OutputDirTemplate(),
-			SkipCleanup:       c.SkipCleanup(),
-			SkipTests:         c.SkipTests(),
-			PostRenderer:      c.PostRenderer(),
-			PostRendererArgs:  c.PostRendererArgs(),
-			KubeVersion:       c.KubeVersion(),
-			ShowOnly:          c.ShowOnly(),
+			Set:                  c.Set(),
+			IncludeCRDs:          c.IncludeCRDs(),
+			NoHooks:              c.NoHooks(),
+			OutputDirTemplate:    c.OutputDirTemplate(),
+			SkipCleanup:          c.SkipCleanup(),
+			SkipTests:            c.SkipTests(),
+			PostRenderer:         c.PostRenderer(),
+			PostRendererArgs:     c.PostRendererArgs(),
+			KubeVersion:          c.KubeVersion(),
+			ShowOnly:             c.ShowOnly(),
+			SkipSchemaValidation: c.SkipSchemaValidation(),
 		}
 		return st.TemplateReleases(helm, c.OutputDir(), c.Values(), args, c.Concurrency(), c.Validate(), opts)
 	})
