@@ -4,8 +4,8 @@ import (
 	"bytes"
 	"io"
 
-	"github.com/goccy/go-yaml"
 	v2 "gopkg.in/yaml.v2"
+	v3 "gopkg.in/yaml.v3"
 
 	"github.com/helmfile/helmfile/pkg/runtime"
 )
@@ -17,19 +17,22 @@ type Encoder interface {
 
 // NewEncoder creates and returns a function that is used to encode a Go object to a YAML document
 func NewEncoder(w io.Writer) Encoder {
-	if runtime.GoccyGoYaml {
-		return yaml.NewEncoder(w)
+	if runtime.GoYamlV3 {
+		v3Encoder := v3.NewEncoder(w)
+		v3Encoder.SetIndent(2)
+		return v3Encoder
 	}
-
 	return v2.NewEncoder(w)
 }
 
-func Unmarshal(data []byte, v any) error {
-	if runtime.GoccyGoYaml {
-		return yaml.Unmarshal(data, v)
-	}
-
-	return v2.Unmarshal(data, v)
+func Marshal(v any) ([]byte, error) {
+	var b bytes.Buffer
+	yamlEncoder := NewEncoder(&b)
+	err := yamlEncoder.Encode(v)
+	defer func() {
+		_ = yamlEncoder.Close()
+	}()
+	return b.Bytes(), err
 }
 
 // NewDecoder creates and returns a function that is used to decode a YAML document
@@ -37,19 +40,9 @@ func Unmarshal(data []byte, v any) error {
 // When strict is true, this function ensures that every field found in the YAML document
 // to have the corresponding field in the decoded Go struct.
 func NewDecoder(data []byte, strict bool) func(any) error {
-	if runtime.GoccyGoYaml {
-		var opts []yaml.DecodeOption
-		if strict {
-			opts = append(opts, yaml.DisallowUnknownField())
-		}
-		// allow duplicate keys
-		opts = append(opts, yaml.AllowDuplicateMapKey())
-
-		decoder := yaml.NewDecoder(
-			bytes.NewReader(data),
-			opts...,
-		)
-
+	if runtime.GoYamlV3 {
+		decoder := v3.NewDecoder(bytes.NewReader(data))
+		decoder.KnownFields(strict)
 		return func(v any) error {
 			return decoder.Decode(v)
 		}
@@ -63,21 +56,10 @@ func NewDecoder(data []byte, strict bool) func(any) error {
 	}
 }
 
-func Marshal(v any) ([]byte, error) {
-	if runtime.GoccyGoYaml {
-		var b bytes.Buffer
-		yamlEncoder := yaml.NewEncoder(
-			&b,
-			yaml.Indent(2),
-			yaml.UseSingleQuote(true),
-			yaml.UseLiteralStyleIfMultiline(true),
-		)
-		err := yamlEncoder.Encode(v)
-		defer func() {
-			_ = yamlEncoder.Close()
-		}()
-		return b.Bytes(), err
+func Unmarshal(data []byte, v any) error {
+	if runtime.GoYamlV3 {
+		return v3.Unmarshal(data, v)
 	}
 
-	return v2.Marshal(v)
+	return v2.Unmarshal(data, v)
 }
